@@ -1,19 +1,20 @@
 """
-    Copyright (C) 2023  Michael Ablassmeier <abi@grinser.de>
+Copyright (C) 2023  Michael Ablassmeier <abi@grinser.de>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
+
 import os
 import string
 import random
@@ -460,6 +461,12 @@ class client:
             domObj.backupBegin(backupXml, checkpointXml)
             log.debug("Started backup job via libvirt API.")
         except libvirt.libvirtError as errmsg:
+            code = errmsg.get_error_code()
+            if code == libvirt.VIR_ERR_CHECKPOINT_INCONSISTENT:
+                raise startBackupFailed(
+                    "Bitmap inconsistency detected: please cleanup checkpoints using virsh "
+                    f"and execute new full backup: {errmsg}"
+                ) from errmsg
             raise startBackupFailed(f"Failed to start backup: [{errmsg}]") from errmsg
         except Exception as e:
             log.exception(e)
